==> rocWMMA-6.4.3.tar.gz: rocWMMA-rocm-6.4.3/test/unit/load_store_matrix_coop_sync_test/test/load_store_matrix_coop_sync_test_params.hpp <==
/*******************************************************************************
 *
 * MIT License
 *
 * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *******************************************************************************/

#ifndef LOAD_STORE_MATRIX_COOP_SYNC_TEST_PARAMS_HPP
#define LOAD_STORE_MATRIX_COOP_SYNC_TEST_PARAMS_HPP
#include <type_traits>

#include "detail/load_store_matrix_coop_sync.hpp"
#include "kernel_generator.hpp"
#include "load_store_matrix_coop_sync_test_params.hpp"
#include "unit_test.hpp"

namespace rocwmma
{

    template <typename Types, typename BlockSizes, typename GeneratorImpl>
    struct LoadStoreMatrixCoopSyncTestParams : public UnitTestParams
    {
        using Base = UnitTestParams;

        // Types: Base IOC
        // Block Sizes: 32 x BlockK
        // Layouts: N, T
        using Layouts      = typename Base::TestLayoutsAll;
        using KernelParams = typename CombineLists<Types, BlockSizes, Layouts>::Result;

        // Assemble the kernel generator
        // Kernel: LoadStoreMatrixCoopSyncB
        using KernelGenerator = KernelGenerator<KernelParams, GeneratorImpl>;

        // Sanity check for kernel generator
        static_assert(std::is_same<typename GeneratorImpl::ResultT, typename Base::KernelT>::value,
                      "Kernels from this generator do not match testing interface");

        static inline typename KernelGenerator::ResultT kernels()
        {
            return KernelGenerator::generate();
        }

        static inline std::vector<Base::Param1T> param1s()
        {
            return {0.0, 1.0}; // Split by waves in same rol and col
        }

        static inline std::vector<Base::Param2T> param2s()
        {
            return
            {
                0.0, 1.0, 2.0,
                    3.0 // 1 - 4 waves
#if ROCWMMA_EXTENDED_TESTS
                    ,
                    4.0, 5.0, 6.0,
                    7.0 // 8 waves
#endif // ROCWMMA_EXTENDED_TESTS
            };
        }
    };
} // namespace rocwmma

#endif // LOAD_STORE_MATRIX_COOP_SYNC_TEST_PARAMS_HPP

==> rocWMMA-7.1.0.tar.gz: rocWMMA-rocm-7.1.0/test/unit/load_store_matrix_coop_sync_test/test/load_store_matrix_coop_sync_test_params.hpp <==
/*******************************************************************************
 *
 * MIT License
 *
 * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 *******************************************************************************/

#ifndef LOAD_STORE_MATRIX_COOP_SYNC_TEST_PARAMS_HPP
#define LOAD_STORE_MATRIX_COOP_SYNC_TEST_PARAMS_HPP
#include <type_traits>

#include <rocwmma/internal/io_scheduler.hpp>

#include "detail/load_store_matrix_coop_sync.hpp"
#include "kernel_generator.hpp"

#include "unit_test.hpp"

namespace rocwmma
{
    template <typename Types, typename BlockSizes, typename GeneratorImpl>
    struct LoadStoreMatrixCoopSyncTestParams : public UnitTestParams
    {
        using Base = UnitTestParams;

        using Schedulers = std::tuple<I<IOScheduler_t::ROW_MAJOR_2D>,
                                      I<IOScheduler_t::ROW_SLICE_2D>
#if ROCWMMA_EXTENDED_TESTS
                                      ,
                                      I<IOScheduler_t::COL_SLICE_2D>,
                                      I<IOScheduler_t::COL_MAJOR_2D>,
                                      I<IOScheduler_t::SINGLE>
#endif // ROCWMMA_EXTENDED_TESTS
                                      >;

        // Types: Base IOC
        // Block Sizes: 32 x BlockK
        // Layouts: N, T
        using Layouts      = typename Base::TestLayoutsAll;
        using KernelParams = typename CombineLists<Types, BlockSizes, Layouts, Schedulers>::Result;

        // Assemble the kernel generator
        // Kernel: LoadStoreMatrixCoopSyncB
        using KernelGenerator = KernelGenerator<KernelParams, GeneratorImpl>;

        // Sanity check for kernel generator
        static_assert(std::is_same<typename GeneratorImpl::ResultT, typename Base::KernelT>::value,
                      "Kernels from this generator do not match testing interface");

        static inline typename KernelGenerator::ResultT kernels()
        {
            return KernelGenerator::generate();
        }
    };
} // namespace rocwmma

#endif // LOAD_STORE_MATRIX_COOP_SYNC_TEST_PARAMS_HPP
